Authors
=======

The original concepts for mosaik were developed by Steffen Schütte and Stefan
Scherfke.

The author of mosaik version 2 is Stefan Scherfke.

Current and former members of the mosaik team: Sharaf Alsharif, Tobias Brandt, Reef Eilers, André El-Ama,
Bengt Lüers, Okko Nannen, Annika Ofenloch, Mostafa Ramezani, Thomas Raub,
Stefan Scherfke, Florian Schloegl, Eike Schulte, Steffen Schütte, Jan Sören Schwarz,
Cornelius Steinbrink, Malte Stomberg, Deborah Tolk
